RwLockBellWriteGuard

Struct RwLockBellWriteGuard 

pub struct RwLockBellWriteGuard<'a, T> { /* private fields */ }
RAII write guard for RwLockBell.

Provides exclusive write access to the protected value via Deref and DerefMut. When dropped, releases the lock and calls all callbacks that were registered via try_write_or while this guard was held.

Obtained via RwLockBell::write, RwLockBell::try_write, or RwLockBell::try_write_or.

Implementations

Source

impl<'a, T> RwLockBellWriteGuard<'a, T>

pub fn map<U, F>(self, f: F) -> MappedRwLockBellWriteGuard<'a, U>
where F: FnOnce(&mut T) -> &mut U,

Transforms this guard into a MappedRwLockBellWriteGuard that dereferences to a subfield of the protected value.

pub fn try_map<U, F>( self, f: F, ) -> Result<MappedRwLockBellWriteGuard<'a, U>, Self>
where F: FnOnce(&mut T) -> Option<&mut U>,

Attempts to transform this guard into a MappedRwLockBellWriteGuard.

Returns Err(self) if f returns None, giving the original guard back.

pub fn try_map_err<U, F, E>( self, f: F, ) -> Result<MappedRwLockBellWriteGuard<'a, U>, (Self, E)>
where F: FnOnce(&mut T) -> Result<&mut U, E>,

Attempts to transform this guard into a MappedRwLockBellWriteGuard.

Returns Err((self, error)) if f returns Err, giving the original guard and the error back.